@@ -111,6 +111,11 @@ const EXEC_TIME_BENCHMARKS: &[(&str, &[&str], Option<i32>)] = &[
     &["run", "cli/tests/testdata/text_encoder_into_perf.js"],
     None,
   ),
+  (
+    "response_string",
+    &["run", "cli/tests/testdata/response_string_perf.js"],
+    None,
+  ),
   (
     "check",
     &[
