@@ -4,7 +4,7 @@ use crate::colors;
 use crate::file_fetcher::get_source_from_data_url;
 use crate::flags::Flags;
 use crate::ops;
-use crate::program_state::ProgramState;
+use crate::proc_state::ProcState;
 use crate::version;
 use deno_core::error::anyhow;
 use deno_core::error::type_error;
@@ -20,7 +20,6 @@ use deno_core::url::Url;
 use deno_core::v8_set_flags;
 use deno_core::ModuleLoader;
 use deno_core::ModuleSpecifier;
-use deno_core::OpState;
 use deno_runtime::deno_broadcast_channel::InMemoryBroadcastChannel;
 use deno_runtime::deno_web::BlobStore;
 use deno_runtime::permissions::Permissions;
@@ -29,7 +28,6 @@ use deno_runtime::worker::MainWorker;
 use deno_runtime::worker::WorkerOptions;
 use deno_tls::create_default_root_cert_store;
 use log::Level;
-use std::cell::RefCell;
 use std::convert::TryInto;
 use std::env::current_exe;
 use std::fs::File;
@@ -127,7 +125,6 @@ struct EmbeddedModuleLoader(String);
 impl ModuleLoader for EmbeddedModuleLoader {
   fn resolve(
     &self,
-    _op_state: Rc<RefCell<OpState>>,
     specifier: &str,
     _referrer: &str,
     _is_main: bool,
@@ -146,7 +143,6 @@ impl ModuleLoader for EmbeddedModuleLoader {
 
   fn load(
     &self,
-    _op_state: Rc<RefCell<OpState>>,
     module_specifier: &ModuleSpecifier,
     _maybe_referrer: Option<ModuleSpecifier>,
     _is_dynamic: bool,
@@ -202,7 +198,7 @@ pub async fn run(
 ) -> Result<(), AnyError> {
   let flags = metadata_to_flags(&metadata);
   let main_module = resolve_url(SPECIFIER)?;
-  let program_state = ProgramState::build(flags).await?;
+  let ps = ProcState::build(flags).await?;
   let permissions = Permissions::from_options(&metadata.permissions);
   let blob_store = BlobStore::default();
   let broadcast_channel = InMemoryBroadcastChannel::default();
@@ -218,7 +214,7 @@ pub async fn run(
       .collect::<Vec<_>>(),
   );
 
-  let mut root_cert_store = program_state
+  let mut root_cert_store = ps
     .root_cert_store
     .clone()
     .unwrap_or_else(create_default_root_cert_store);
@@ -265,7 +261,7 @@ pub async fn run(
     js_runtime
       .op_state()
       .borrow_mut()
-      .put::<Arc<ProgramState>>(program_state.clone());
+      .put::<ProcState>(ps.clone());
     ops::errors::init(js_runtime);
     ops::runtime_compiler::init(js_runtime);
     js_runtime.sync_ops_cache();
