@@ -1,15 +1,10 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
-import {
-  assert,
-  assertThrows,
-  assertThrowsAsync,
-  unitTest,
-} from "./test_util.ts";
+import { assert, assertRejects, assertThrows, unitTest } from "./test_util.ts";
 
 const REMOVE_METHODS = ["remove", "removeSync"] as const;
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeDirSuccess() {
     for (const method of REMOVE_METHODS) {
       // REMOVE EMPTY DIRECTORY
@@ -27,7 +22,7 @@ unitTest(
 );
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeFileSuccess() {
     for (const method of REMOVE_METHODS) {
       // REMOVE FILE
@@ -47,7 +42,7 @@ unitTest(
 );
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeFileByUrl() {
     for (const method of REMOVE_METHODS) {
       // REMOVE FILE
@@ -72,7 +67,7 @@ unitTest(
 );
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeFail() {
     for (const method of REMOVE_METHODS) {
       // NON-EMPTY DIRECTORY
@@ -85,13 +80,13 @@ unitTest(
       const subPathInfo = Deno.statSync(subPath);
       assert(subPathInfo.isDirectory); // check exist first
 
-      await assertThrowsAsync(async () => {
+      await assertRejects(async () => {
         await Deno[method](path);
       }, Error);
       // TODO(ry) Is Other really the error we should get here? What would Go do?
 
       // NON-EXISTENT DIRECTORY/FILE
-      await assertThrowsAsync(async () => {
+      await assertRejects(async () => {
         await Deno[method]("/baddir");
       }, Deno.errors.NotFound);
     }
@@ -99,7 +94,7 @@ unitTest(
 );
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeDanglingSymlinkSuccess() {
     for (const method of REMOVE_METHODS) {
       const danglingSymlinkPath = Deno.makeTempDirSync() + "/dangling_symlink";
@@ -121,7 +116,7 @@ unitTest(
 );
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeValidSymlinkSuccess() {
     for (const method of REMOVE_METHODS) {
       const encoder = new TextEncoder();
@@ -146,16 +141,16 @@ unitTest(
   },
 );
 
-unitTest({ perms: { write: false } }, async function removePerm() {
+unitTest({ permissions: { write: false } }, async function removePerm() {
   for (const method of REMOVE_METHODS) {
-    await assertThrowsAsync(async () => {
+    await assertRejects(async () => {
       await Deno[method]("/baddir");
     }, Deno.errors.PermissionDenied);
   }
 });
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeAllDirSuccess() {
     for (const method of REMOVE_METHODS) {
       // REMOVE EMPTY DIRECTORY
@@ -192,7 +187,7 @@ unitTest(
 );
 
 unitTest(
-  { perms: { write: true, read: true } },
+  { permissions: { write: true, read: true } },
   async function removeAllFileSuccess() {
     for (const method of REMOVE_METHODS) {
       // REMOVE FILE
@@ -212,19 +207,19 @@ unitTest(
   },
 );
 
-unitTest({ perms: { write: true } }, async function removeAllFail() {
+unitTest({ permissions: { write: true } }, async function removeAllFail() {
   for (const method of REMOVE_METHODS) {
     // NON-EXISTENT DIRECTORY/FILE
-    await assertThrowsAsync(async () => {
+    await assertRejects(async () => {
       // Non-existent
       await Deno[method]("/baddir", { recursive: true });
     }, Deno.errors.NotFound);
   }
 });
 
-unitTest({ perms: { write: false } }, async function removeAllPerm() {
+unitTest({ permissions: { write: false } }, async function removeAllPerm() {
   for (const method of REMOVE_METHODS) {
-    await assertThrowsAsync(async () => {
+    await assertRejects(async () => {
       await Deno[method]("/baddir", { recursive: true });
     }, Deno.errors.PermissionDenied);
   }
@@ -233,7 +228,7 @@ unitTest({ perms: { write: false } }, async function removeAllPerm() {
 unitTest(
   {
     ignore: Deno.build.os === "windows",
-    perms: { write: true, read: true },
+    permissions: { write: true, read: true },
   },
   async function removeUnixSocketSuccess() {
     for (const method of REMOVE_METHODS) {
@@ -253,7 +248,7 @@ unitTest(
 
 if (Deno.build.os === "windows") {
   unitTest(
-    { perms: { run: true, write: true, read: true } },
+    { permissions: { run: true, write: true, read: true } },
     async function removeFileSymlink() {
       const symlink = Deno.run({
         cmd: ["cmd", "/c", "mklink", "file_link", "bar"],
@@ -263,14 +258,14 @@ if (Deno.build.os === "windows") {
       assert(await symlink.status());
       symlink.close();
       await Deno.remove("file_link");
-      await assertThrowsAsync(async () => {
+      await assertRejects(async () => {
         await Deno.lstat("file_link");
       }, Deno.errors.NotFound);
     },
   );
 
   unitTest(
-    { perms: { run: true, write: true, read: true } },
+    { permissions: { run: true, write: true, read: true } },
     async function removeDirSymlink() {
       const symlink = Deno.run({
         cmd: ["cmd", "/c", "mklink", "/d", "dir_link", "bar"],
@@ -281,7 +276,7 @@ if (Deno.build.os === "windows") {
       symlink.close();
 
       await Deno.remove("dir_link");
-      await assertThrowsAsync(async () => {
+      await assertRejects(async () => {
         await Deno.lstat("dir_link");
       }, Deno.errors.NotFound);
     },
