@@ -7,7 +7,7 @@ import {
   unitTest,
 } from "./test_util.ts";
 
-function assertMissing(path: string): void {
+function assertMissing(path: string) {
   let caughtErr = false;
   let info;
   try {
@@ -20,12 +20,12 @@ function assertMissing(path: string): void {
   assertEquals(info, undefined);
 }
 
-function assertFile(path: string): void {
+function assertFile(path: string) {
   const info = Deno.lstatSync(path);
   assert(info.isFile);
 }
 
-function assertDirectory(path: string, mode?: number): void {
+function assertDirectory(path: string, mode?: number) {
   const info = Deno.lstatSync(path);
   assert(info.isDirectory);
   if (Deno.build.os !== "windows" && mode !== undefined) {
@@ -34,8 +34,8 @@ function assertDirectory(path: string, mode?: number): void {
 }
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function renameSyncSuccess(): void {
+  { permissions: { read: true, write: true } },
+  function renameSyncSuccess() {
     const testDir = Deno.makeTempDirSync();
     const oldpath = testDir + "/oldpath";
     const newpath = testDir + "/newpath";
@@ -47,8 +47,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function renameSyncWithURL(): void {
+  { permissions: { read: true, write: true } },
+  function renameSyncWithURL() {
     const testDir = Deno.makeTempDirSync();
     const oldpath = testDir + "/oldpath";
     const newpath = testDir + "/newpath";
@@ -63,8 +63,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: false, write: true } },
-  function renameSyncReadPerm(): void {
+  { permissions: { read: false, write: true } },
+  function renameSyncReadPerm() {
     assertThrows(() => {
       const oldpath = "/oldbaddir";
       const newpath = "/newbaddir";
@@ -74,8 +74,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: false } },
-  function renameSyncWritePerm(): void {
+  { permissions: { read: true, write: false } },
+  function renameSyncWritePerm() {
     assertThrows(() => {
       const oldpath = "/oldbaddir";
       const newpath = "/newbaddir";
@@ -85,8 +85,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function renameSuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function renameSuccess() {
     const testDir = Deno.makeTempDirSync();
     const oldpath = testDir + "/oldpath";
     const newpath = testDir + "/newpath";
@@ -98,8 +98,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function renameWithURL(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function renameWithURL() {
     const testDir = Deno.makeTempDirSync();
     const oldpath = testDir + "/oldpath";
     const newpath = testDir + "/newpath";
@@ -119,15 +119,18 @@ function readFileString(filename: string): string {
   return dec.decode(dataRead);
 }
 
-function writeFileString(filename: string, s: string): void {
+function writeFileString(filename: string, s: string) {
   const enc = new TextEncoder();
   const data = enc.encode(s);
   Deno.writeFileSync(filename, data, { mode: 0o666 });
 }
 
 unitTest(
-  { ignore: Deno.build.os === "windows", perms: { read: true, write: true } },
-  function renameSyncErrorsUnix(): void {
+  {
+    ignore: Deno.build.os === "windows",
+    permissions: { read: true, write: true },
+  },
+  function renameSyncErrorsUnix() {
     const testDir = Deno.makeTempDirSync();
     const oldfile = testDir + "/oldfile";
     const olddir = testDir + "/olddir";
@@ -141,21 +144,21 @@ unitTest(
     writeFileString(file, "world");
 
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(oldfile, emptydir);
       },
       Error,
       "Is a directory",
     );
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(olddir, fulldir);
       },
       Error,
       "Directory not empty",
     );
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(olddir, file);
       },
       Error,
@@ -170,21 +173,21 @@ unitTest(
     Deno.symlinkSync(testDir + "/nonexistent", danglingLink);
 
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(olddir, fileLink);
       },
       Error,
       "Not a directory",
     );
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(olddir, dirLink);
       },
       Error,
       "Not a directory",
     );
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(olddir, danglingLink);
       },
       Error,
@@ -201,8 +204,11 @@ unitTest(
 );
 
 unitTest(
-  { ignore: Deno.build.os !== "windows", perms: { read: true, write: true } },
-  function renameSyncErrorsWin(): void {
+  {
+    ignore: Deno.build.os !== "windows",
+    permissions: { read: true, write: true },
+  },
+  function renameSyncErrorsWin() {
     const testDir = Deno.makeTempDirSync();
     const oldfile = testDir + "/oldfile";
     const olddir = testDir + "/olddir";
@@ -216,21 +222,21 @@ unitTest(
     writeFileString(file, "world");
 
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(oldfile, emptydir);
       },
       Deno.errors.PermissionDenied,
       "Access is denied",
     );
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(olddir, fulldir);
       },
       Deno.errors.PermissionDenied,
       "Access is denied",
     );
     assertThrows(
-      (): void => {
+      () => {
         Deno.renameSync(olddir, emptydir);
       },
       Deno.errors.PermissionDenied,
