@@ -1,15 +1,15 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
 import {
   assertEquals,
+  assertRejects,
   assertThrows,
-  assertThrowsAsync,
   pathToAbsoluteFileUrl,
   unitTest,
 } from "./test_util.ts";
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function futimeSyncSuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function futimeSyncSuccess() {
     const testDir = await Deno.makeTempDir();
     const filename = testDir + "/file.txt";
     const file = await Deno.open(filename, {
@@ -30,8 +30,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function futimeSyncSuccess(): void {
+  { permissions: { read: true, write: true } },
+  function futimeSyncSuccess() {
     const testDir = Deno.makeTempDirSync();
     const filename = testDir + "/file.txt";
     const file = Deno.openSync(filename, {
@@ -52,8 +52,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function utimeSyncFileSuccess(): void {
+  { permissions: { read: true, write: true } },
+  function utimeSyncFileSuccess() {
     const testDir = Deno.makeTempDirSync();
     const filename = testDir + "/file.txt";
     Deno.writeFileSync(filename, new TextEncoder().encode("hello"), {
@@ -71,8 +71,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function utimeSyncUrlSuccess(): void {
+  { permissions: { read: true, write: true } },
+  function utimeSyncUrlSuccess() {
     const testDir = Deno.makeTempDirSync();
     const filename = testDir + "/file.txt";
     Deno.writeFileSync(filename, new TextEncoder().encode("hello"), {
@@ -90,8 +90,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function utimeSyncDirectorySuccess(): void {
+  { permissions: { read: true, write: true } },
+  function utimeSyncDirectorySuccess() {
     const testDir = Deno.makeTempDirSync();
 
     const atime = 1000;
@@ -105,8 +105,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function utimeSyncDateSuccess(): void {
+  { permissions: { read: true, write: true } },
+  function utimeSyncDateSuccess() {
     const testDir = Deno.makeTempDirSync();
 
     const atime = new Date(1000_000);
@@ -120,7 +120,7 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
+  { permissions: { read: true, write: true } },
   function utimeSyncFileDateSuccess() {
     const testDir = Deno.makeTempDirSync();
     const filename = testDir + "/file.txt";
@@ -138,8 +138,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function utimeSyncLargeNumberSuccess(): void {
+  { permissions: { read: true, write: true } },
+  function utimeSyncLargeNumberSuccess() {
     const testDir = Deno.makeTempDirSync();
 
     // There are Rust side caps (might be fs relate),
@@ -155,8 +155,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function utimeSyncNotFound(): void {
+  { permissions: { read: true, write: true } },
+  function utimeSyncNotFound() {
     const atime = 1000;
     const mtime = 50000;
 
@@ -167,8 +167,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: false } },
-  function utimeSyncPerm(): void {
+  { permissions: { read: true, write: false } },
+  function utimeSyncPerm() {
     const atime = 1000;
     const mtime = 50000;
 
@@ -179,8 +179,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function utimeFileSuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function utimeFileSuccess() {
     const testDir = Deno.makeTempDirSync();
     const filename = testDir + "/file.txt";
     Deno.writeFileSync(filename, new TextEncoder().encode("hello"), {
@@ -198,8 +198,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function utimeUrlSuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function utimeUrlSuccess() {
     const testDir = Deno.makeTempDirSync();
     const filename = testDir + "/file.txt";
     Deno.writeFileSync(filename, new TextEncoder().encode("hello"), {
@@ -217,8 +217,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function utimeDirectorySuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function utimeDirectorySuccess() {
     const testDir = Deno.makeTempDirSync();
 
     const atime = 1000;
@@ -232,8 +232,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function utimeDateSuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function utimeDateSuccess() {
     const testDir = Deno.makeTempDirSync();
 
     const atime = new Date(100_000);
@@ -247,8 +247,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function utimeFileDateSuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function utimeFileDateSuccess() {
     const testDir = Deno.makeTempDirSync();
     const filename = testDir + "/file.txt";
     Deno.writeFileSync(filename, new TextEncoder().encode("hello"), {
@@ -266,24 +266,24 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function utimeNotFound(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function utimeNotFound() {
     const atime = 1000;
     const mtime = 50000;
 
-    await assertThrowsAsync(async () => {
+    await assertRejects(async () => {
       await Deno.utime("/baddir", atime, mtime);
     }, Deno.errors.NotFound);
   },
 );
 
 unitTest(
-  { perms: { read: true, write: false } },
-  async function utimeSyncPerm(): Promise<void> {
+  { permissions: { read: true, write: false } },
+  async function utimeSyncPerm() {
     const atime = 1000;
     const mtime = 50000;
 
-    await assertThrowsAsync(async () => {
+    await assertRejects(async () => {
       await Deno.utime("/some_dir", atime, mtime);
     }, Deno.errors.PermissionDenied);
   },
