@@ -4,7 +4,7 @@ use crate::colors;
 use crate::file_fetcher::File;
 use crate::flags::Flags;
 use crate::get_types;
-use crate::program_state::ProgramState;
+use crate::proc_state::ProcState;
 use crate::write_json_to_stdout;
 use crate::write_to_stdout_ignore_sigpipe;
 use deno_ast::MediaType;
@@ -61,7 +61,7 @@ impl Resolver for DocResolver {
 }
 
 struct DocLoader {
-  program_state: Arc<ProgramState>,
+  ps: ProcState,
 }
 
 impl Loader for DocLoader {
@@ -71,9 +71,9 @@ impl Loader for DocLoader {
     _is_dynamic: bool,
   ) -> LoadFuture {
     let specifier = specifier.clone();
-    let program_state = self.program_state.clone();
+    let ps = self.ps.clone();
     async move {
-      let result = program_state
+      let result = ps
         .file_fetcher
         .fetch(&specifier, &mut Permissions::allow_all())
         .await
@@ -97,7 +97,7 @@ pub async fn print_docs(
   maybe_filter: Option<String>,
   private: bool,
 ) -> Result<(), AnyError> {
-  let program_state = ProgramState::build(flags.clone()).await?;
+  let ps = ProcState::build(flags.clone()).await?;
   let source_file = source_file.unwrap_or_else(|| "--builtin".to_string());
   let source_parser = deno_graph::DefaultSourceParser::new();
 
@@ -135,13 +135,11 @@ pub async fn print_docs(
     };
 
     // Save our fake file into file fetcher cache.
-    program_state.file_fetcher.insert_cached(root);
+    ps.file_fetcher.insert_cached(root);
 
-    let mut loader = DocLoader {
-      program_state: program_state.clone(),
-    };
+    let mut loader = DocLoader { ps: ps.clone() };
     let resolver = DocResolver {
-      import_map: program_state.maybe_import_map.clone(),
+      import_map: ps.maybe_import_map.clone(),
     };
     let graph = create_graph(
       root_specifier.clone(),
